-----------------------------------------------------------
-----------------------------------------------------------
-- Archivo de creacin de la base de datos y de las tablas
-- para Catlogo Web
-- Proyecto Fin de Carrera de Pablo Lpez Lpez
-----------------------------------------------------------
-----------------------------------------------------------


-----------------------------------------
-----------------------------------------
-- Se crea la base de datos: catwebDB
-----------------------------------------
-----------------------------------------

CREATE DATABASE IF NOT EXISTS catwebDB;


-------------------------------------------
-------------------------------------------
-- Se crean las tablas de la base de datos
-------------------------------------------
-------------------------------------------

-------------------------------------------
-- Se crea la tabla: Discos
-------------------------------------------

CREATE TABLE IF NOT EXISTS Discos (
	IDdisco INTEGER NOT NULL auto_increment,
	Nombre VARCHAR(60) NOT NULL,
	Autor VARCHAR(20) NOT NULL,
	Existencias INTEGER NOT NULL,
	Reservados INTEGER NOT NULL,
	Anno INTEGER,
	Duracion INTEGER,
	Discografica VARCHAR(20),
	PRIMARY KEY (IDdisco),
	CONSTRAINT nome1 UNIQUE (Nombre, Autor)
);



-------------------------------------------
-- Se crea la tabla: Usuarios
-------------------------------------------
-- Tipousuario
--
-- 1 Cliente
-- 2 Administrador
-- 3 Vendedor
-- 4 Almacenista
-------------------------------------------

CREATE TABLE IF NOT EXISTS Usuarios (
	IDusuario INTEGER NOT NULL auto_increment,
	Usuario VARCHAR(60) NOT NULL,
	Contrasea VARCHAR(10) UNIQUE NOT NULL,
	Tipousuario INTEGER NOT NULL,
	PRIMARY KEY (IDusuario)
);



-------------------------------------------
-- Se crea la tabla: Reservas
-------------------------------------------

CREATE TABLE IF NOT EXISTS Reservas (
	IDdisco INTEGER NOT NULL,
	IDusuario INTEGER NOT NULL,
	Fecha DATE,
	PRIMARY KEY (IDdisco, IDusuario),
	FOREIGN KEY (IDdisco) REFERENCES Discos(IDdisco),
	FOREIGN KEY (IDusuario) REFERENCES Usuarios(IDusuario)
);




-------------------------------------------
-------------------------------------------
-- Se insertan valores en la tabla Discos
-------------------------------------------
-------------------------------------------

INSERT INTO Discos (Nombre, Autor, Existencias,Reservados, Anno, Duracion, Discografica)
	VALUES	   ('Live at Tokio',
		'Dream Theater',
		4,
		1,
		2004,
		95,
		'Atlantic');

INSERT INTO Discos (Nombre, Autor, Existencias,Reservados, Anno, Duracion, Discografica)
	VALUES	   ('Budokan',
		'Dream Theater',
		7,
		0,
		2005,
		78,
		'Atlantic');

INSERT INTO Discos (Nombre, Autor, Existencias,Reservados, Anno, Duracion, Discografica)
	VALUES	   ('Concierto para violn 1041',
		'Bach',
		6,
		0,
		1983,
		14,
		'Archiv');

INSERT INTO Discos (Nombre, Autor, Existencias,Reservados, Anno, Duracion, Discografica)
	VALUES	   ('Concierto para violn 1042',
		'Bach',
		6,
		0,
		1983,
		15,
		'Archiv');

INSERT INTO Discos (Nombre, Autor, Existencias,Reservados, Anno, Duracion, Discografica)
	VALUES	   ('Suites para cello',
		'Bach',
		6,
		0,
		1995,
		78,
		'EMI');

INSERT INTO Discos (Nombre, Autor, Existencias,Reservados, Anno, Duracion, Discografica)
	VALUES	   ('Conciertos para violn',
		'Vivaldi',
		6,
		0,
		1986,
		67,
		'Archiv');

INSERT INTO Discos (Nombre, Autor, Existencias,Reservados, Anno, Duracion, Discografica)
	VALUES	   ('Las cuatro estaciones',
		'Vivaldi',
		6,
		0,
		1987,
		45,
		'Naxos');

INSERT INTO Discos (Nombre, Autor, Existencias,Reservados, Anno, Duracion, Discografica)
	VALUES	   ('Concerti grossi',
		'Handel',
		6,
		0,
		1982,
		42,
		'Archiv');

INSERT INTO Discos (Nombre, Autor, Existencias,Reservados, Anno, Duracion, Discografica)
	VALUES	   ('Msica acuatica',
		'Handel',
		6,
		0,
		1988,
		34,
		'Naxos');

INSERT INTO Discos (Nombre, Autor, Existencias,Reservados, Anno, Duracion, Discografica)
	VALUES	   ('Msica para los fuegos artificiales',
		'Handel',
		6,
		0,
		1988,
		32,
		'Naxos');

INSERT INTO Discos (Nombre, Autor, Existencias,Reservados, Anno, Duracion, Discografica)
	VALUES	   ('Concierto piano 1',
		'Beethoven',
		6,
		0,
		1992,
		30,
		'Planeta');

INSERT INTO Discos (Nombre, Autor, Existencias,Reservados, Anno, Duracion, Discografica)
	VALUES	   ('Concierto para violn',
		'Beethoven',
		6,
		0,
		1962,
		45,
		'Deutsche grammophon');


INSERT INTO Discos (Nombre, Autor, Existencias,Reservados, Anno, Duracion, Discografica)
	VALUES	   ('Sinfonia 9',
		'Beethoven',
		6,
		0,
		1981,
		72,
		'Deutsche grammophon');



--------------------------------------------
--------------------------------------------
-- Se insertan valores en la tabla Usuarios
--------------------------------------------
--------------------------------------------

INSERT INTO Usuarios (Usuario, Contrasea, Tipousuario)
	VALUES	   ('carmen',
		'carmen23',
		1);

INSERT INTO Usuarios (Usuario, Contrasea, Tipousuario)
	VALUES	   ('pablo',
		'pablo34',
		1);

INSERT INTO Usuarios (Usuario, Contrasea, Tipousuario)
	VALUES	   ('administrador',
		'adm123',
		2);

INSERT INTO Usuarios (Usuario, Contrasea, Tipousuario)
	VALUES	   ('vendedor1',
		'vend1',
		3);

INSERT INTO Usuarios (Usuario, Contrasea, Tipousuario)
	VALUES	   ('vendedor2',
		'vend2',
		3);

INSERT INTO Usuarios (Usuario, Contrasea, Tipousuario)
	VALUES	   ('almacen1',
		'alma1',
		4);

INSERT INTO Usuarios (Usuario, Contrasea, Tipousuario)
	VALUES	   ('almacen2',
		'alma2',
		4);




--------------------------------------------
--------------------------------------------
-- Se insertan valores en la tabla Reservas
--------------------------------------------
--------------------------------------------

INSERT INTO Reservas (IDdisco, IDUsuario, Fecha)
	VALUES	   (1,
		1,
		20041223);